@@ -148,9 +148,9 @@ if args.run in ['run', 'Run', 'RUN']:
 
     symbols = []
     for symbol in args.symbol.split(','):
-        if args.symbol in ['BTCUSD', 'Bitcoin', 'bitcoin', 'XBTUSD', 'BTC', 'btc', 'btcusd']:
+        if symbol in ['BTCUSD', 'Bitcoin', 'bitcoin', 'XBTUSD', 'BTC', 'btc', 'btcusd']:
             symbols.append('XBTUSD')
-        if args.symbol in ['ETHUSD', 'Ethereum', 'ethereum', 'ETH', 'eth', 'ethusd']:
+        if symbol in ['ETHUSD', 'Ethereum', 'ethereum', 'ETH', 'eth', 'ethusd']:
             symbols.append('ETHUSD')
     if not symbols:
         print("No recognizable Symbol found. Supported are 'ETHUSD' and 'BTCUSD'.")
